@@ -41,7 +41,7 @@ class MetaMax extends CMSModule
 
   function GetVersion()
   {
-    return '2.1';
+    return '2.1.1';
   }
 
   function GetHelp()
