@@ -84,6 +84,8 @@ switch($current_version)
  case "1.9.9.8":
  case "1.9.9.9":
  case "2.0":
+ case "2.1":
+ case "2.1.1":
 }
 
 // put mention into the admin log
